System.register([], (function (exports) {
	'use strict';
	return {
		execute: (function () {

			var main = exports('default', { one: { two: { three: { four: 42 } } } });

		})
	};
}));
